#!/usr/bin/env python

"""Factory for error calculation algorithms allowed for usage."""

# Standard library

# 3rd party packages

# Local source
from parametrization_clean.domain.cost.strategy import IErrorStrategy
from parametrization_clean.domain.cost.reax_error import ReaxError


class ErrorFactory:
    """Factory class for creating error calculator algorithm executor - RegistryHolder design pattern.
    Classes that implement IErrorStrategy can be registered and utilized through this factory's registry.
    """

    # Internal registry for available crossover methods
    REGISTRY = {}

    @classmethod
    def register(cls, algorithm_name: str, mutation_class):
        """Register a class with a string key."""
        cls.REGISTRY[algorithm_name] = mutation_class
        return mutation_class

    @classmethod
    def create_executor(cls, algorithm_name: str) -> IErrorStrategy:
        return cls.REGISTRY[algorithm_name]


ErrorFactory.register('reax_error', ReaxError)



#!/usr/bin/env python

"""Factory for adaptation algorithms allowed for usage."""

# Standard library

# 3rd party packages

# Local source
from parametrization_clean.domain.adaptation.strategy import IAdaptationStrategy
from parametrization_clean.domain.adaptation.srinivas import SrinivasAdapt
from parametrization_clean.domain.adaptation.xiao import XiaoAdapt


class AdaptationFactory:
    """Factory class for creating adaptation algorithm executor - RegistryHolder design pattern.
    Classes that implement IAdaptationStrategy can be registered and utilized through this factory's registry.
    """

    # Internal registry for available crossover methods
    REGISTRY = {}

    @classmethod
    def register(cls, algorithm_name: str, mutation_class):
        """Register a class with a string key."""
        cls.REGISTRY[algorithm_name] = mutation_class
        return mutation_class

    @classmethod
    def create_executor(cls, algorithm_name: str) -> IAdaptationStrategy:
        return cls.REGISTRY[algorithm_name]


AdaptationFactory.register('srinivas', SrinivasAdapt)
AdaptationFactory.register('xiao', XiaoAdapt)



#!/usr/bin/env python

"""Factory for mutation algorithms allowed for usage."""

# Standard library

# 3rd party packages

# Local source
from parametrization_clean.domain.mutation.strategy import IMutationStrategy
from parametrization_clean.domain.mutation.central_uniform import CentralUniformMutate
from parametrization_clean.domain.mutation.nakata import NakataMutate
from parametrization_clean.domain.mutation.gauss import GaussianMutate
from parametrization_clean.domain.mutation.polynomial import PolynomialMutate


class MutationFactory:
    """Factory class for creating mutation algorithm executor - RegistryHolder design pattern.
    Classes that implement IMutationStrategy can be registered and utilized through this factory's registry.
    """

    # Internal registry for available crossover methods
    REGISTRY = {}

    @classmethod
    def register(cls, algorithm_name: str, mutation_class):
        """Register a class with a string key."""
        cls.REGISTRY[algorithm_name] = mutation_class
        return mutation_class

    @classmethod
    def create_executor(cls, algorithm_name: str) -> IMutationStrategy:
        return cls.REGISTRY[algorithm_name]


# Register all existing mutation algorithms
MutationFactory.register('central_uniform', CentralUniformMutate)
MutationFactory.register('nakata', NakataMutate)
MutationFactory.register('gauss', GaussianMutate)
MutationFactory.register('polynomial', PolynomialMutate)



#!/usr/bin/env python

"""Factory for crossover algorithms allowed for usage."""

# Standard library

# 3rd party packages

# Local source
from parametrization_clean.domain.crossover.strategy import ICrossoverStrategy
from parametrization_clean.domain.crossover.single_point import SinglePointCross
from parametrization_clean.domain.crossover.two_point import TwoPointCross
from parametrization_clean.domain.crossover.uniform import UniformCross
from parametrization_clean.domain.crossover.double_pareto import DoubleParetoCross


class CrossoverFactory:
    """Factory class for creating crossover algorithm executor - RegistryHolder design pattern.
    Classes that implement ICrossoverStrategy can be registered and utilized through this factory's registry.
    """

    # Internal registry for available crossover methods
    REGISTRY = {}

    @classmethod
    def register(cls, algorithm_name: str, mutation_class):
        """Register a class with a string key."""
        cls.REGISTRY[algorithm_name] = mutation_class
        return mutation_class

    @classmethod
    def create_executor(cls, algorithm_name: str) -> ICrossoverStrategy:
        return cls.REGISTRY[algorithm_name]


CrossoverFactory.register('single_point', SinglePointCross)
CrossoverFactory.register('two_point', TwoPointCross)
CrossoverFactory.register('uniform', UniformCross)
CrossoverFactory.register('double_pareto', DoubleParetoCross)
